BalderHub Waveform
====================================

This is a BalderHub project that provides different kind of objects for working with Waveforms. It holds a database of ready to use Waveforms that can be sent to programmable test instruments like signal generators.

.. note::
   Please note, this package is still under development. If you would like to contribute, take a look into the
   `project <https://github.com/balder-dev/balderhub-waveform/>`_.

This is a BalderHub package for the `Balder <https://docs.balder.dev/>`_ test framework. If you are new to Balder check
out the `official documentation <https://docs.balder.dev>`_ first.


.. toctree::
   :maxdepth: 2

   installation.rst
   topic_intro.rst
   scenarios.rst
   features.rst
   examples.rst
   utilities.rst
